/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: call_data.proto */

#ifndef PROTOBUF_C_call_5fdata_2eproto__INCLUDED
#define PROTOBUF_C_call_5fdata_2eproto__INCLUDED

#include <protobuf-c/protobuf-c.h>

PROTOBUF_C__BEGIN_DECLS

#if PROTOBUF_C_VERSION_NUMBER < 1003000
# error This file was generated by a newer version of protoc-c which is incompatible with your libprotobuf-c headers. Please update your headers.
#elif 1004001 < PROTOBUF_C_MIN_COMPILER_VERSION
# error This file was generated by an older version of protoc-c which is incompatible with your libprotobuf-c headers. Please regenerate this file with a newer version of protoc-c.
#endif

#include "pytypes.pb-c.h"

typedef struct Carp__CallData Carp__CallData;
typedef struct Carp__CallResponse Carp__CallResponse;


/* --- enums --- */


/* --- messages --- */

struct  Carp__CallData
{
  ProtobufCMessage base;
  int64_t call_id;
  char *host_id;
  int64_t instance_id;
  char *service_name;
  Carp__PythonArray *args;
  Carp__PythonDict *kwargs;
};
#define CARP__CALL_DATA__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&carp__call_data__descriptor) \
    , 0, (char *)protobuf_c_empty_string, 0, (char *)protobuf_c_empty_string, NULL, NULL }


struct  Carp__CallResponse
{
  ProtobufCMessage base;
  int64_t call_id;
  char *host_id;
  char *service_name;
  Carp__PythonValue *value;
  char *exception;
};
#define CARP__CALL_RESPONSE__INIT \
 { PROTOBUF_C_MESSAGE_INIT (&carp__call_response__descriptor) \
    , 0, (char *)protobuf_c_empty_string, (char *)protobuf_c_empty_string, NULL, (char *)protobuf_c_empty_string }


/* Carp__CallData methods */
void   carp__call_data__init
                     (Carp__CallData         *message);
size_t carp__call_data__get_packed_size
                     (const Carp__CallData   *message);
size_t carp__call_data__pack
                     (const Carp__CallData   *message,
                      uint8_t             *out);
size_t carp__call_data__pack_to_buffer
                     (const Carp__CallData   *message,
                      ProtobufCBuffer     *buffer);
Carp__CallData *
       carp__call_data__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   carp__call_data__free_unpacked
                     (Carp__CallData *message,
                      ProtobufCAllocator *allocator);
/* Carp__CallResponse methods */
void   carp__call_response__init
                     (Carp__CallResponse         *message);
size_t carp__call_response__get_packed_size
                     (const Carp__CallResponse   *message);
size_t carp__call_response__pack
                     (const Carp__CallResponse   *message,
                      uint8_t             *out);
size_t carp__call_response__pack_to_buffer
                     (const Carp__CallResponse   *message,
                      ProtobufCBuffer     *buffer);
Carp__CallResponse *
       carp__call_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data);
void   carp__call_response__free_unpacked
                     (Carp__CallResponse *message,
                      ProtobufCAllocator *allocator);
/* --- per-message closures --- */

typedef void (*Carp__CallData_Closure)
                 (const Carp__CallData *message,
                  void *closure_data);
typedef void (*Carp__CallResponse_Closure)
                 (const Carp__CallResponse *message,
                  void *closure_data);

/* --- services --- */


/* --- descriptors --- */

extern const ProtobufCMessageDescriptor carp__call_data__descriptor;
extern const ProtobufCMessageDescriptor carp__call_response__descriptor;

PROTOBUF_C__END_DECLS


#endif  /* PROTOBUF_C_call_5fdata_2eproto__INCLUDED */
