/* Generated by the protocol buffer compiler.  DO NOT EDIT! */
/* Generated from: call_data.proto */

/* Do not generate deprecated warnings for self */
#ifndef PROTOBUF_C__NO_DEPRECATED
#define PROTOBUF_C__NO_DEPRECATED
#endif

#include "call_data.pb-c.h"
void   carp__call_data__init
                     (Carp__CallData         *message)
{
  static const Carp__CallData init_value = CARP__CALL_DATA__INIT;
  *message = init_value;
}
size_t carp__call_data__get_packed_size
                     (const Carp__CallData *message)
{
  assert(message->base.descriptor == &carp__call_data__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__call_data__pack
                     (const Carp__CallData *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__call_data__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__call_data__pack_to_buffer
                     (const Carp__CallData *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__call_data__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__CallData *
       carp__call_data__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__CallData *)
     protobuf_c_message_unpack (&carp__call_data__descriptor,
                                allocator, len, data);
}
void   carp__call_data__free_unpacked
                     (Carp__CallData *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__call_data__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
void   carp__call_response__init
                     (Carp__CallResponse         *message)
{
  static const Carp__CallResponse init_value = CARP__CALL_RESPONSE__INIT;
  *message = init_value;
}
size_t carp__call_response__get_packed_size
                     (const Carp__CallResponse *message)
{
  assert(message->base.descriptor == &carp__call_response__descriptor);
  return protobuf_c_message_get_packed_size ((const ProtobufCMessage*)(message));
}
size_t carp__call_response__pack
                     (const Carp__CallResponse *message,
                      uint8_t       *out)
{
  assert(message->base.descriptor == &carp__call_response__descriptor);
  return protobuf_c_message_pack ((const ProtobufCMessage*)message, out);
}
size_t carp__call_response__pack_to_buffer
                     (const Carp__CallResponse *message,
                      ProtobufCBuffer *buffer)
{
  assert(message->base.descriptor == &carp__call_response__descriptor);
  return protobuf_c_message_pack_to_buffer ((const ProtobufCMessage*)message, buffer);
}
Carp__CallResponse *
       carp__call_response__unpack
                     (ProtobufCAllocator  *allocator,
                      size_t               len,
                      const uint8_t       *data)
{
  return (Carp__CallResponse *)
     protobuf_c_message_unpack (&carp__call_response__descriptor,
                                allocator, len, data);
}
void   carp__call_response__free_unpacked
                     (Carp__CallResponse *message,
                      ProtobufCAllocator *allocator)
{
  if(!message)
    return;
  assert(message->base.descriptor == &carp__call_response__descriptor);
  protobuf_c_message_free_unpacked ((ProtobufCMessage*)message, allocator);
}
static const ProtobufCFieldDescriptor carp__call_data__field_descriptors[6] =
{
  {
    "call_id",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT64,
    0,   /* quantifier_offset */
    offsetof(Carp__CallData, call_id),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "host_id",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Carp__CallData, host_id),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "instance_id",
    3,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT64,
    0,   /* quantifier_offset */
    offsetof(Carp__CallData, instance_id),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "service_name",
    4,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Carp__CallData, service_name),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "args",
    5,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(Carp__CallData, args),
    &carp__python_array__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "kwargs",
    6,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(Carp__CallData, kwargs),
    &carp__python_dict__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__call_data__field_indices_by_name[] = {
  4,   /* field[4] = args */
  0,   /* field[0] = call_id */
  1,   /* field[1] = host_id */
  2,   /* field[2] = instance_id */
  5,   /* field[5] = kwargs */
  3,   /* field[3] = service_name */
};
static const ProtobufCIntRange carp__call_data__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 6 }
};
const ProtobufCMessageDescriptor carp__call_data__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.CallData",
  "CallData",
  "Carp__CallData",
  "carp",
  sizeof(Carp__CallData),
  6,
  carp__call_data__field_descriptors,
  carp__call_data__field_indices_by_name,
  1,  carp__call_data__number_ranges,
  (ProtobufCMessageInit) carp__call_data__init,
  NULL,NULL,NULL    /* reserved[123] */
};
static const ProtobufCFieldDescriptor carp__call_response__field_descriptors[5] =
{
  {
    "call_id",
    1,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_INT64,
    0,   /* quantifier_offset */
    offsetof(Carp__CallResponse, call_id),
    NULL,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "host_id",
    2,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Carp__CallResponse, host_id),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "service_name",
    3,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Carp__CallResponse, service_name),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "value",
    4,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_MESSAGE,
    0,   /* quantifier_offset */
    offsetof(Carp__CallResponse, value),
    &carp__python_value__descriptor,
    NULL,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
  {
    "exception",
    5,
    PROTOBUF_C_LABEL_NONE,
    PROTOBUF_C_TYPE_STRING,
    0,   /* quantifier_offset */
    offsetof(Carp__CallResponse, exception),
    NULL,
    &protobuf_c_empty_string,
    0,             /* flags */
    0,NULL,NULL    /* reserved1,reserved2, etc */
  },
};
static const unsigned carp__call_response__field_indices_by_name[] = {
  0,   /* field[0] = call_id */
  4,   /* field[4] = exception */
  1,   /* field[1] = host_id */
  2,   /* field[2] = service_name */
  3,   /* field[3] = value */
};
static const ProtobufCIntRange carp__call_response__number_ranges[1 + 1] =
{
  { 1, 0 },
  { 0, 5 }
};
const ProtobufCMessageDescriptor carp__call_response__descriptor =
{
  PROTOBUF_C__MESSAGE_DESCRIPTOR_MAGIC,
  "carp.CallResponse",
  "CallResponse",
  "Carp__CallResponse",
  "carp",
  sizeof(Carp__CallResponse),
  5,
  carp__call_response__field_descriptors,
  carp__call_response__field_indices_by_name,
  1,  carp__call_response__number_ranges,
  (ProtobufCMessageInit) carp__call_response__init,
  NULL,NULL,NULL    /* reserved[123] */
};
