# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: call_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import pytypes_pb2 as pytypes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63\x61ll_data.proto\x12\x04\x63\x61rp\x1a\rpytypes.proto\"\x9a\x01\n\x08\x43\x61llData\x12\x0f\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x12\x0f\n\x07host_id\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\x03\x12\x14\n\x0cservice_name\x18\x04 \x01(\t\x12\x1f\n\x04\x61rgs\x18\x05 \x01(\x0b\x32\x11.carp.PythonArray\x12 \n\x06kwargs\x18\x06 \x01(\x0b\x32\x10.carp.PythonDict\"{\n\x0c\x43\x61llResponse\x12\x0f\n\x07\x63\x61ll_id\x18\x01 \x01(\x03\x12\x0f\n\x07host_id\x18\x02 \x01(\t\x12\x14\n\x0cservice_name\x18\x03 \x01(\t\x12 \n\x05value\x18\x04 \x01(\x0b\x32\x11.carp.PythonValue\x12\x11\n\texception\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'call_data_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CALLDATA._serialized_start=41
  _CALLDATA._serialized_end=195
  _CALLRESPONSE._serialized_start=197
  _CALLRESPONSE._serialized_end=320
# @@protoc_insertion_point(module_scope)
